@@ -1,4 +1,24 @@
-"""JMetalpy operators
+# Copyright (C) 2019- Centre of Biological Engineering,
+#     University of Minho, Portugal
+
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+"""
+##############################################################################
+Genetic operators for jmetalpy 
+
+Authors: Vitor Pereira
+##############################################################################
 """
 
 import copy
@@ -66,10 +86,12 @@ class GrowMutationKO(Mutation[KOSolution]):
         """
         if random.random() <= self.probability and solution.number_of_variables < self.max_size:
             mutant = copy.copy(solution.variables)
-            newElem = random.randint(solution.lower_bound, solution.upper_bound)
-            while newElem in mutant:
-                newElem = random.randint(solution.lower_bound, solution.upper_bound)
-            mutant.append(newElem)
+            idx = random.randint(solution.lower_bound, solution.upper_bound)
+            while idx in mutant:
+                idx = idx + 1
+                if idx > solution.upper_bound:
+                    idx = solution.lower_bound
+            mutant.append(idx)
             solution.variables = mutant
             solution.number_of_variables = len(mutant)
         return solution
@@ -103,7 +125,9 @@ class GrowMutationOU(Mutation[OUSolution]):
             idx = random.randint(solution.lower_bound[0], solution.upper_bound[0])
             idxs = [a for (a, b) in mutant]
             while idx in idxs:
-                idx = random.randint(solution.lower_bound[0], solution.upper_bound[0])
+                idx = idx + 1
+                if idx > solution.upper_bound[0]:
+                    idx = solution.lower_bound[0]
             lv = random.randint(solution.lower_bound[1], solution.upper_bound[1])
             mutant.append((idx, lv))
             solution.variables = mutant
@@ -265,13 +289,16 @@ class SingleMutationKO(Mutation[KOSolution]):
         super(SingleMutationKO, self).__init__(probability=probability)
 
     def execute(self, solution: Solution) -> Solution:
-        if random.random() <= self.probability:
+        n = solution.upper_bound-solution.lower_bound+1
+        if random.random() <= self.probability and solution.number_of_variables < n:
             mutant = copy.copy(solution.variables)
             index = random.randint(0, len(mutant) - 1)
-            newElem = random.randint(solution.lower_bound, solution.upper_bound)
-            while newElem in mutant:
-                newElem = random.randint(solution.lower_bound, solution.upper_bound)
-            mutant[index] = newElem
+            idx = random.randint(solution.lower_bound, solution.upper_bound)
+            while idx in mutant:
+                idx = idx + 1
+                if idx > solution.upper_bound:
+                    idx = solution.lower_bound
+            mutant[index] = idx
             solution.variables = mutant
         return solution
 
@@ -288,7 +315,8 @@ class SingleMutationOU(Mutation[OUSolution]):
         super(SingleMutationOU, self).__init__(probability=probability)
 
     def execute(self, solution: Solution) -> Solution:
-        if random.random() <= self.probability:
+        n = solution.upper_bound[0]-solution.lower_bound[0]+1
+        if random.random() <= self.probability and solution.number_of_variables < n:
             mutant = copy.copy(solution.variables)
             lix = [i for (i, j) in mutant]
             index = random.randint(0, len(mutant) - 1)
@@ -297,7 +325,9 @@ class SingleMutationOU(Mutation[OUSolution]):
             if random.random() > 0.5:
                 idx = random.randint(solution.lower_bound[0], solution.upper_bound[0])
                 while idx in lix:
-                    idx = random.randint(solution.lower_bound[0], solution.upper_bound[0])
+                    idx = idx+1
+                    if idx > solution.upper_bound[0]:
+                       idx = solution.lower_bound[0]
                 is_mutate_idx = True
             lv = random.randint(solution.lower_bound[1], solution.upper_bound[1])
             if not is_mutate_idx:
@@ -322,7 +352,6 @@ class SingleMutationOULevel(Mutation[OUSolution]):
     def execute(self, solution: Solution) -> Solution:
         if random.random() <= self.probability:
             mutant = copy.copy(solution.variables)
-            x = len(mutant)
             index = random.randint(0, len(mutant) - 1)
             idx, idy = mutant[index]
             lv = random.randint(solution.lower_bound[1], solution.upper_bound[1])
