@@ -1,3 +1,25 @@
+# Copyright (C) 2019- Centre of Biological Engineering,
+#     University of Minho, Portugal
+
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+"""
+##############################################################################
+Kinetic optimization problems.
+
+Author: Vitor Pereira
+##############################################################################
+"""
 from mewpy.problems.problem import AbstractKOProblem, AbstractOUProblem
 from mewpy.optimization.evaluation import KineticEvaluationFunction
 from mewpy.simulation.kinetic import KineticSimulation
@@ -23,13 +45,16 @@ class KineticKOProblem(AbstractKOProblem):
                 raise ValueError(f"The optimization function {f} is not intended for kinetic optimization.")
 
     def _build_target_list(self):
+        """ Generates a target list, set of Vmax variable.
+            It expects Vmax variables to be defined as "?max".
+        """
         p = list(self.model.get_parameters(exclude_compartments=True))
         target =[]
         for k in p:
             if search(r'(?i)[rv]max',k):
                 target.append(k)
         if self.non_target is not None:
-            target = target - set(self.non_target)
+            target = set(target) - set(self.non_target)
         self._trg_list = list(target)
 
     def decode(self, candidate):
@@ -64,6 +89,9 @@ class KineticOUProblem(AbstractOUProblem):
                 raise ValueError(f"The optimization function {f} is not intended for kinetic optimization.")
 
     def _build_target_list(self):
+        """ Generates a target list, set of Vmax variable.
+            It expect Vmax variables beeing defined as "?max".
+        """
         p = list(self.model.get_parameters(exclude_compartments=True))
         target =[]
         for k in p:
