@@ -57,6 +57,7 @@ class CobraModelContainer(ModelContainer):
     def __init__(self, model: Model = None):
         self.model = model
 
+
     @property
     def id(self):
         """The model identifier."""
@@ -327,7 +328,9 @@ class Simulation(CobraModelContainer, Simulator):
                      ub=ModelConstants.REACTION_UPPER_BOUND,
                      gpr=None,
                      objective=0,
-                     replace=True, **kwargs):
+                     replace=True,
+                     annotations={},
+                     reaction_type=None):
         """Adds a reaction to the model
 
         :param rxn_id: The reaction identifier
@@ -363,7 +366,7 @@ class Simulation(CobraModelContainer, Simulator):
         reaction.upper_bound = ub
         if gpr and isinstance(gpr, str):
             reaction.gene_reaction_rule = gpr
-
+        reaction.annotation = annotations
         if replace and rxn_id in self.reactions:
             self.remove_reaction(rxn_id)
         self.model.add_reactions([reaction])
@@ -677,8 +680,8 @@ class Simulation(CobraModelContainer, Simulator):
         else:
             return variability
 
-    def set_objective(self, reaction):
-        self.model.objective = reaction
+    def set_objective(self, reaction_id:str):
+        self.model.objective = reaction_id
 
     def create_empty_model(self, model_id: str):
         return Simulation(Model(model_id))
